Enum linfa_preprocessing::linear_scaling::ScalingMethod[][src]

pub enum ScalingMethod<F: Float> {
    Standard(boolbool),
    MinMax(F, F),
    MaxAbs,
}

Possible scaling methods for LinearScaler

  • Standard (with mean, with std): subtracts the mean to each feature and scales it by the inverse of its standard deviation
  • MinMax (min, max): scales each feature to fit in the range [min,max], default values are [0,1]
  • MaxAbs: scales each feature by the inverse of its maximum absolute value, so that it fits the range [-1,1]

Variants

Standard(boolbool)
MinMax(F, F)
MaxAbs