Struct linfa_preprocessing::linear_scaling::FittedLinearScaler[][src]

pub struct FittedLinearScaler<F: Float> { /* fields omitted */ }

The result of fitting a linear scaler. Scales datasets with the parameters learned during fitting.

Implementations

impl<F: Float> FittedLinearScaler<F>[src]

pub fn offsets(&self) -> &Array1<F>[src]

Array of size n_features that contains the offset that will be subtracted to each feature

pub fn scales(&self) -> &Array1<F>[src]

Array of size n_features that contains the scale that will be applied to each feature

pub fn method(&self) -> &ScalingMethod<F>[src]

Returns the method used for fitting. Useful for printing, since ScalingMethod implements Display