pub struct LinearScaler<F: Float> { /* private fields */ }Expand description
The result of fitting a linear scaler. Scales datasets with the parameters learned during fitting.
Implementations
Sourceimpl<F: Float> LinearScaler<F>
impl<F: Float> LinearScaler<F>
Sourcepub fn standard() -> LinearScalerParams<F>
pub fn standard() -> LinearScalerParams<F>
Initializes a Standard scaler
Sourcepub fn standard_no_mean() -> LinearScalerParams<F>
pub fn standard_no_mean() -> LinearScalerParams<F>
Initializes a Standard scaler that does not subract the mean to the features
Sourcepub fn standard_no_std() -> LinearScalerParams<F>
pub fn standard_no_std() -> LinearScalerParams<F>
Initializes a Stadard scaler that does not scale the features by the inverse of the standard deviation
Sourcepub fn min_max() -> LinearScalerParams<F>
pub fn min_max() -> LinearScalerParams<F>
Initializes a MinMax scaler with range 0..=1
Sourcepub fn min_max_range(min: F, max: F) -> LinearScalerParams<F>
pub fn min_max_range(min: F, max: F) -> LinearScalerParams<F>
Initializes a MinMax scaler with the specified minimum and maximum values for the range.
If min is bigger than max then fitting will return an error on any input.
Sourcepub fn max_abs() -> LinearScalerParams<F>
pub fn max_abs() -> LinearScalerParams<F>
Initializes a MaxAbs scaler
Sourceimpl<F: Float> LinearScaler<F>
impl<F: Float> LinearScaler<F>
Sourcepub fn offsets(&self) -> &Array1<F>
pub fn offsets(&self) -> &Array1<F>
Array of size n_features that contains the offset that will be subtracted to each feature
Sourcepub fn scales(&self) -> &Array1<F>
pub fn scales(&self) -> &Array1<F>
Array of size n_features that contains the scale that will be applied to each feature
Sourcepub fn method(&self) -> &ScalingMethod<F>
pub fn method(&self) -> &ScalingMethod<F>
Returns the method used for fitting. Useful for printing, since ScalingMethod implements Display