Struct linfa_preprocessing::whitening::Whitener
source · [−]pub struct Whitener { /* private fields */ }Expand description
Struct that can be fitted to the input data to obtain the related whitening matrix. Fitting returns a FittedWhitener struct that can be used to apply the whitening transformation to the input data.
Implementations
sourceimpl Whitener
impl Whitener
sourcepub fn cholesky() -> Self
pub fn cholesky() -> Self
Creates an instance of a Whitener that uses the cholesky decomposition of the inverse of the covariance matrix
pub fn method(self, method: WhiteningMethod) -> Self