Module linfa_preprocessing::tf_idf_vectorization [−][src]
Term frequency - inverse document frequency vectorization methods
Structs
| FittedTfIdfVectorizer | Counts the occurrences of each vocabulary entry, learned during fitting, in a sequence of texts and scales them by the inverse document document frequency defined by the method. Each vocabulary entry is mapped to an integer value that is used to index the count in the result. |
| TfIdfVectorizer | Simlar to |
Enums
| TfIdfMethod | Methods for computing the inverse document frequency of a vocabulary entry |