Module linfa_preprocessing::whitening[][src]

Methods for uncorrelating data

Whitening refers to a collection of methods that, given in input a matrix X of records with covariance matrix = sigma, output a whitening matrix W such that W.T dot W = sigma. Appliyng the whitening matrix W to the input data gives a new data matrix Y of the same size as the input such that Y has unit diagonal (white) covariance matrix.

Structs

FittedWhitener

Struct that can be used to whiten data. Data will be scaled according to the whitening matrix learned during fitting. Obtained by fitting a Whitener.

Whitener

Struct that can be fitted to the input data to obtain the related whitening matrix. Fitting returns a FittedWhitener struct that can be used to apply the whitening transformation to the input data.

Enums

WhiteningMethod