Struct linfa_preprocessing::whitening::Whitener [−][src]
pub struct Whitener { /* fields omitted */ }Struct that can be fitted to the input data to obtain the related whitening matrix. Fitting returns a FittedWhitener struct that can be used to apply the whitening transformation to the input data.
Implementations
impl Whitener[src]
impl Whitener[src]pub fn pca() -> Self[src]
Creates an instance of a Whitener that uses the PCA method
pub fn zca() -> Self[src]
Creates an instance of a Whitener that uses the ZCA (Mahalanobis) method
pub fn cholesky() -> Self[src]
Creates an instance of a Whitener that uses the cholesky decomposition of the inverse of the covariance matrix
pub fn method(self, method: WhiteningMethod) -> Self[src]